pub enum DeprecatedSince {
RustcVersion(RustcVersion),
Future,
NonStandard(Ustr),
Unspecified,
Err,
}Expand description
Release in which an API is deprecated.
Variants
RustcVersion(RustcVersion)
Future
Deprecated in the future (“to be determined”).
NonStandard(Ustr)
feature(staged_api) is off. Deprecation versions outside the standard
library are allowed to be arbitrary strings, for better or worse.
Unspecified
Deprecation version is unspecified but optional.
Err
Failed to parse a deprecation version, or the deprecation version is unspecified and required. An error has already been emitted.